@@ -206,8 +206,8 @@ class MarkRecommendationClaimedRequest(proto.Message):
         state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationClaimedRequest.StateMetadataEntry]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
-            ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the regex
-            ``/^[a-zA-Z0-9_./-]{0,255}$/``.
+            ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
+            regex ``/^[a-zA-Z0-9_./-]{0,255}$/``.
         etag (str):
             Required. Fingerprint of the Recommendation.
             Provides optimistic locking.
@@ -227,8 +227,8 @@ class MarkRecommendationSucceededRequest(proto.Message):
         state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationSucceededRequest.StateMetadataEntry]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
-            ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the regex
-            ``/^[a-zA-Z0-9_./-]{0,255}$/``.
+            ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
+            regex ``/^[a-zA-Z0-9_./-]{0,255}$/``.
         etag (str):
             Required. Fingerprint of the Recommendation.
             Provides optimistic locking.
@@ -248,8 +248,8 @@ class MarkRecommendationFailedRequest(proto.Message):
         state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationFailedRequest.StateMetadataEntry]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
-            ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the regex
-            ``/^[a-zA-Z0-9_./-]{0,255}$/``.
+            ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
+            regex ``/^[a-zA-Z0-9_./-]{0,255}$/``.
         etag (str):
             Required. Fingerprint of the Recommendation.
             Provides optimistic locking.
